@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro;
 
 use Mojolicious::Lite;
 
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 
 use feature qw( state );
 
@@ -32,9 +32,11 @@ post '/' => sub {
         return;
     }
 
-    if ( !$params->{TRXTYPE}
+    if (
+        !$params->{TRXTYPE}
         || none { $params->{TRXTYPE} eq $_ }
-        ( 'A', 'C', 'D', 'I', 'S', 'V', ) ) {
+        ( 'A', 'C', 'D', 'I', 'S', 'V', )
+        ) {
         $c->render( text => 'Mocked URL not found', status => 404 );
         return;
     }
@@ -249,7 +251,7 @@ WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro - A simple app to enabl
 
 =head1 VERSION
 
-version 0.000017
+version 0.000018
 
 =head1 DESCRIPTION
 
