@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Response::FromHTTP;
 
 use Moo;
 
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 
 use MooX::HandlesVia;
 use MooX::StrictConstructor;
@@ -38,14 +38,15 @@ has _request_uri => (
 
 sub BUILD {
     my $self = shift;
-    return if $self->_http_response->is_success;
+    return
+        if $self->_http_response->is_success
+        && !$self->_http_response->header('X-Died');
 
-    WebService::PayPal::PaymentsAdvanced::Error::HTTP->throw(
-        message       => 'HTTP error: ' . $self->_code,
+    WebService::PayPal::PaymentsAdvanced::Error::HTTP
+        ->throw_from_http_response(
         http_response => $self->_http_response,
-        http_status   => $self->_code,
         request_uri   => $self->_request_uri,
-    );
+        );
 }
 
 sub _build_params {
@@ -64,7 +65,7 @@ WebService::PayPal::PaymentsAdvanced::Response::FromHTTP - Response object for W
 
 =head1 VERSION
 
-version 0.000017
+version 0.000018
 
 =head1 DESCRIPTION
 
